# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Python 2 dropped in Fedora 32, RHEL-8
%if %([ "(" "%{__distinit}" == "fc" -a %{__distvers} -lt 32 ")" -o "(" "%{__distinit}" == "rhel" -a %{__distvers} -lt 8 ")" ] && echo 1 || echo 0)
%global with_python2 1
%global main_python  %{__python2}
%global other_python %{__python3}
%else
%global with_python2 0
%global main_python %{__python3}
%endif

# Disable Xpointer locations support from Fedora 40 as per the Fedora package
%if %([ "(" "%{__distinit}" == "fc" -a %{__distvers} -lt 40 ")" -o "(" "%{__distinit}" == "rhel" -a %{__distvers} -lt 10 ")" ] && echo 1 || echo 0)
%global with_xptr_locs 1
%else
%global with_xptr_locs 0
%endif

# Single python3 version in Fedora, python3_pkgversion macro not available
%{!?python3_pkgversion:%global python3_pkgversion 3}

# For consistency and completeness
%global python2_pkgversion 2

# For -O3 on ppc64 (#1051068)
%global _performance_build 1

%if %{with_python2}
%global python2ver %(%{__python2} -c "import sys; print sys.version[:3]" 2>/dev/null || echo none)
%endif
%global python3ver %(%{__python3} -c "import sys; sys.stdout.write('{0.major}.{0.minor}'.format(sys.version_info))" 2>/dev/null || echo none)

Summary:	Library providing XML and HTML support
Name:		libxml2
Version:	2.12.10
Release:	1.0.cf.%{__distinit}%{__distvers}
# list.c, dict.c and few others use ISC-Veillard
# the conformance and test suite data in
# Source1, Source2 and Source3 is covered by W3C
License:	MIT AND ISC-Veillard AND W3C
URL:		https://gitlab.gnome.org/GNOME/libxml2/-/wikis/home
Source0:	https://download.gnome.org/sources/libxml2/2.12/libxml2-%{version}.tar.xz
# https://www.w3.org/XML/Test/xmlconf-20080827.html
Source1:	https://www.w3.org/XML/Test/xmlts20080827.tar.gz
# https://www.w3.org/XML/2004/xml-schema-test-suite/index.html
Source2:	https://www.w3.org/XML/2004/xml-schema-test-suite/xmlschema2002-01-16/xsts-2002-01-16.tar.gz
Source3:	https://www.w3.org/XML/2004/xml-schema-test-suite/xmlschema2004-01-14/xsts-2004-01-14.tar.gz
Patch0:		libxml2-multilib.patch
Patch1:		libxml2-2.12.0-python3-unicode-errors.patch
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	pkgconfig
%if %{with_python2}
BuildRequires:	python%{python2_pkgversion}, python%{python2_pkgversion}-devel
%endif
BuildRequires:	python%{python3_pkgversion}, python%{python3_pkgversion}-devel
BuildRequires:	sed
BuildRequires:	xz-devel%{?_isa}
BuildRequires:	zlib-devel%{?_isa}

# Don't drop bogus provide for python shared object as it's required by python-dmidecode (surely a packaging bug?)
#global __provides_exclude ^libxml2mod\\.so

%description
This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select sub-nodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.

%package devel
Summary:	Libraries, includes, etc. to develop XML and HTML applications
Requires:	libxml2%{?_isa} = %{version}-%{release}
Requires:	pkgconfig
Requires:	xz-devel%{?_isa}
Requires:	zlib-devel%{?_isa}

%description devel
Libraries, include files, etc you can use to develop XML applications.
This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select sub-nodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.

%package static
Summary:	Static library for libxml2
Requires:	libxml2-devel%{?_isa} = %{version}-%{release}

%description static
Static library for libxml2 provided for specific uses or shaving a few
microseconds when parsing, do not link to them for generic purpose packages.

%if %{with_python2}
%package -n python%{python2_pkgversion}-%{name}
Summary:	Python 2 bindings for the libxml2 library
Requires:	libxml2%{?_isa} = %{version}-%{release}
Obsoletes:	%{name}-python < %{version}-%{release}
Provides:	%{name}-python = %{version}-%{release}
Provides:	%{name}-python%{?_isa} = %{version}-%{release}
Obsoletes:	python-%{name} < %{version}-%{release}
Provides:	python-%{name} = %{version}-%{release}
Provides:	python-%{name}%{?_isa} = %{version}-%{release}

%description -n python2-%{name}
The python%{python2_pkgversion}-libxml2 package contains a Python 2 module that permits
applications written in the Python programming language, version 2, to use
the interface supplied by the libxml2 library to manipulate XML files.

This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DTDs, either
at parse time or later once the document has been modified.
%endif

%package -n python%{python3_pkgversion}-%{name}
Summary:	Python 3 bindings for the libxml2 library
Requires:	libxml2%{?_isa} = %{version}-%{release}
Obsoletes:	%{name}-python3 < %{version}-%{release}
Provides:	%{name}-python3 = %{version}-%{release}
Provides:	%{name}-python3%{?_isa} = %{version}-%{release}
%if "%{python3_pkgversion}" != "3"
Obsoletes:	python3-%{name} < %{version}-%{release}
Provides:	python3-%{name} = %{version}-%{release}
Provides:	python3-%{name}%{?_isa} = %{version}-%{release}
%endif

%description -n python%{python3_pkgversion}-%{name}
The python%{python3_pkgversion}-libxml2 package contains a Python 3 module that permits
applications written in the Python programming language, version 3, to use
the interface supplied by the libxml2 library to manipulate XML files.

This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DTDs, either
at parse time or later once the document has been modified.

%prep
%setup -q

# Avoid multilib file conflicts
%patch -P 0

# Fix unicode errors in Python 3 (patch from openSUSE)
# https://bugzilla.gnome.org/show_bug.cgi?id=789714
%patch -P 1 -p1

# Fix bogus exec permissions
find . \( -name '*.c' -o -name '*.py' \) -exec chmod -c 644 {} \;

# We'll ship compressed versions of some documentation
gzip -9c < doc/libxml2-api.xml > doc/libxml2-api.xml.gz

# Create a separate source tree for the python3 build if necessary
%if 0%{?other_python:1} && 0%{?py3dir:1}
rm -rf %{py3dir}
cp -a . %{py3dir}
%endif

# Fix shellbangs on python3 examples
mkdir py3doc
cp -a doc/*.py py3doc
sed -i 's|#!/usr/bin/python |#!%{__python3} |' py3doc/*.py

%build
export PYTHON=%{main_python}
%configure \
	--enable-static \
	--with-ftp \
	--with-legacy \
%if %{with_xptr_locs}
	--with-xptr-locs \
%endif
	--with-python
make %{_smp_mflags} V=1

%if 0%{?other_python:1} && 0%{?py3dir:1}
pushd %{py3dir}
export PYTHON=%{other_python}
%configure \
	--enable-static \
	--with-ftp \
	--with-legacy \
%if %{with_xptr_locs}
	--with-xptr-locs \
%endif
	--with-python
make %{_smp_mflags} V=1
popd
%endif

%install
%if 0%{?other_python:1} && 0%{?py3dir:1}
# Do the python3 install first so that the python2 version is used
# for anything installed into the same locations
pushd %{py3dir}
make DESTDIR=%{buildroot} INSTALL="install -p" install
popd
%endif

make DESTDIR=%{buildroot} INSTALL="install -p" install

# Remove files we don't want packaged
rm -rf %{buildroot}%{_libdir}/*.la
%if %{with_python2}
rm -f %{buildroot}%{_libdir}/python%{python2ver}/site-packages/libxml2mod.{a,la}
%endif
rm -f %{buildroot}%{_libdir}/python%{python3ver}/site-packages/libxml2mod.{a,la}

# We'll package the documentation ourselves
rm -r %{buildroot}%{_datadir}/doc/libxml2/

# Multiarch crazyness on timestamp differences or Makefile/binaries for examples
touch -m --reference=%{buildroot}%{_includedir}/libxml2/libxml/parser.h %{buildroot}%{_bindir}/xml2-config

%check
# Tests require the XML conformance suite
tar -xzvf %{SOURCE1}
make check
rm -rf xmlconf

# Schema tests use the schema test suite
cp %{SOURCE2} %{SOURCE3} xstc/
pushd xstc
mkdir Tests
make tests
popd

# As the directory is copied to the devel subpackage, remove any build artefacts
(cd doc/examples; make clean; rm -rf .deps Makefile)

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig replaced by RPM File Triggers from Fedora 28
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%license Copyright
%doc NEWS README.md
%{_bindir}/xmlcatalog
%{_bindir}/xmllint
%{_libdir}/libxml2.so.2*
%{_mandir}/man1/xmlcatalog.1*
%{_mandir}/man1/xmllint.1*

%files devel
%doc doc/*.html
%doc doc/tutorial doc/libxml2-api.xml.gz
# Note: examples/writer.xml and examples/testWriter.c explicitly encoded as ISO-8859-1
%doc doc/examples
%doc %dir %{_datadir}/gtk-doc/html/libxml2/
%doc %{_datadir}/gtk-doc/html/libxml2/*.devhelp2
%doc %{_datadir}/gtk-doc/html/libxml2/*.html
%doc %{_datadir}/gtk-doc/html/libxml2/*.png
%doc %{_datadir}/gtk-doc/html/libxml2/*.css
%{_libdir}/libxml2.so
%{_bindir}/xml2-config
%{_libdir}/cmake/libxml2/
%{_libdir}/pkgconfig/libxml-2.0.pc
%{_includedir}/libxml2/
%{_datadir}/aclocal/libxml.m4
%{_mandir}/man1/xml2-config.1*

%files static
%{_libdir}/libxml2.a

%if %{with_python2}
%files -n python%{python2_pkgversion}-%{name}
%doc python/libxml2class.txt
%doc doc/*.py
%{_prefix}/lib/python%{python2ver}/site-packages/libxml2.py*
%{_prefix}/lib/python%{python2ver}/site-packages/drv_libxml2.py*
%{_libdir}/python%{python2ver}/site-packages/libxml2mod.so
%endif

%files -n python%{python3_pkgversion}-%{name}
%doc python/libxml2class.txt
%doc py3doc/*.py
%{_prefix}/lib/python%{python3ver}/site-packages/libxml2.py*
%{_prefix}/lib/python%{python3ver}/site-packages/drv_libxml2.py*
%if "%{python3ver}" != "3.1"
%{_prefix}/lib/python%{python3ver}/site-packages/__pycache__/libxml2.cpython-%(echo %{python3ver} | tr -d .)*.py*
%{_prefix}/lib/python%{python3ver}/site-packages/__pycache__/drv_libxml2.cpython-%(echo %{python3ver} | tr -d .)*.py*
%endif
%{_libdir}/python%{python3ver}/site-packages/libxml2mod.so

%changelog
* Mon Mar 17 2025 Paul Howarth <paul@city-fan.org> - 2.12.10-1.0.cf
- Update to 2.12.10
  Security:
  - Fix stack-buffer-overflow in xmlSnprintfElements (CVE-2025-24928)
  - Fix use-after-free after xmlSchemaItemListAdd (CVE-2024-56171)
  - pattern: Fix compilation of explicit child axis
  Regressions:
  - parser: Fix detection of duplicate attributes
  Bug fixes:
  - xpath: Fix parsing of non-ASCII names
  Portability:
  - python: Declare init func with PyMODINIT_FUNC
  - tests: Fix sanitizer version check on old Apple clang
  Build:
  - autotools: Set AC_CONFIG_AUX_DIR
  - cmake: Always build Python module as shared library
  - cmake: Fix compatibility in package version file

* Fri Jan 17 2025 Paul Howarth <paul@city-fan.org> - 2.12.9-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Dec 27 2024 Paul Howarth <paul@city-fan.org> - 2.12.9-1.0.cf
- Update to 2.12.9
  Security:
  - Fix XXE protection in downstream code (CVE-2024-40896)
  Improvements:
  - Undeprecate xmlKeepBlanksDefault

* Fri Jul 19 2024 Paul Howarth <paul@city-fan.org> - 2.12.8-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Thu Jun 13 2024 Paul Howarth <paul@city-fan.org> - 2.12.8-1.0.cf
- Update to 2.12.8
  Regressions:
  - parser: Fix performance regression when parsing namespaces

* Wed May 22 2024 Paul Howarth <paul@city-fan.org> - 2.12.7-1.0.cf
- Update to 2.12.7
  Security:
  - Fix buffer overread with 'xmllint --htmlout' (CVE-2024-34459)
  Regressions:
  - xmllint: Fix --pedantic option
  - save: Handle invalid parent pointers in xhtmlNodeDumpOutput

* Mon Mar 18 2024 Paul Howarth <paul@city-fan.org> - 2.12.6-1.0.cf
- Update to 2.12.6
  Regressions:
  - parser: Fix detection of duplicate attributes in XML namespace
  - xmlreader: Fix xmlTextReaderConstEncoding
  - html: Fix htmlCreatePushParserCtxt with encoding
  - xmllint: Return error code if XPath returns empty nodeset

* Mon Feb  5 2024 Paul Howarth <paul@city-fan.org> - 2.12.5-1.0.cf
- Update to 2.12.5
  Security:
  - xmlreader: Don't expand XIncludes when backtracking (CVE-2024-25062)
  Regressions:
  - parser: Fix crash in xmlParseInNodeContext with HTML documents

* Thu Jan 25 2024 Paul Howarth <paul@city-fan.org> - 2.12.4-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 19 2024 Paul Howarth <paul@city-fan.org> - 2.12.4-2.0.cf
- Update to 2.12.4
  Regressions:
  - parser: Fix regression parsing standalone declarations
  - autotools: Re-add --with-xptr-locs configuration option
  - parser: Fix build --without-output
  - parser: Don't grow or shrink pull parser memory buffers
  - io: Fix memory lifetime issue with input buffers
- Update license to include ISC-Veillard
- Reinstate Xpointer locations support for Fedora < 40, RHEL < 10

* Wed Dec 13 2023 Paul Howarth <paul@city-fan.org> - 2.12.3-1.0.cf
- Update to 2.12.3
  Regressions:
  - parser: Fix namespaces redefined from default attributes
  Build fixes:
  - include: Rename XML_EMPTY helper macro
  - include: Move declaration of xmlInitGlobals
  - include: Add missing includes
  - include: Move globals from xmlsave.h to parser.h
  - include: Re-add circular dependency between tree.h and parser.h
- Disable Xpointer locations support as per the Fedora package

* Wed Dec  6 2023 Paul Howarth <paul@city-fan.org> - 2.12.2-1.0.cf
- Update to 2.12.2
  Regressions:
  - parser: Fix invalid free in xmlParseBalancedChunkMemoryRecover
  - globals: Disable TLS in static Windows builds
  - html: Reenable buggy detection of XML declarations
  - tree: Fix regression when copying DTDs
  - parser: Make CRLF increment line number
  Build fixes:
  - build: Disable compiler TLS by default
  - cmake: Update config.h.cmake.in
  - tests: Fix tests --with-valid --without-xinclude
- Enable W3C XML Conformance and Schema test suites

* Tue Nov 28 2023 Paul Howarth <paul@city-fan.org> - 2.12.1-1.0.cf
- Update to 2.12.1
  Regressions:
  - hash: Fix deletion of entries during scan
  - parser: Only enable SAX2 if there are SAX2 element handlers
  Build fixes:
  - autotools: Stop checking for snprintf
  - dict: Fix '__thread' before 'static'
  - Fix: pthread weak references in globals.c
  - tests: Fix build with older MSVC

* Mon Nov 20 2023 Paul Howarth <paul@city-fan.org> - 2.12.0-1.0.cf
- Update to 2.12.0 (see NEWS for details)

* Tue Aug 22 2023 Paul Howarth <paul@city-fan.org> - 2.11.5-1.0.cf
- Update to 2.11.5 (see NEWS for details)

* Thu Jul 20 2023 Paul Howarth <paul@city-fan.org> - 2.10.4-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jul  5 2023 Paul Howarth <paul@city-fan.org> - 2.10.4-2.0.cf
- Rebuilt for Python 3.12

* Thu Apr 13 2023 Paul Howarth <paul@city-fan.org> - 2.10.4-1.0.cf
- Update to 2.10.4 (see NEWS for details)
  - [CVE-2023-29469] Hashing of empty dict strings isn't deterministic
  - [CVE-2023-28484] Fix null deref in xmlSchemaFixupComplexType
- Avoid use of deprecated patch syntax

* Fri Jan 20 2023 Paul Howarth <paul@city-fan.org> - 2.10.3-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Nov  4 2022 Paul Howarth <paul@city-fan.org> - 2.10.3-2.0.cf
- Set build options to maintain (most) symbols from 2.9.14 (#2139546)

* Tue Nov  1 2022 Paul Howarth <paul@city-fan.org> - 2.10.3-1.1.cf
- Include FTP support prior to Fedora 37 (#2136800)

* Thu Oct 20 2022 Paul Howarth <paul@city-fan.org> - 2.10.3-1.0.cf
- Update to 2.10.3 (see NEWS for details)
  - [CVE-2022-2309] Reset nsNr in xmlCtxtReset
  - [CVE-2022-40304] Fix dict corruption caused by entity reference cycles
  - [CVE-2022-40303] Fix integer overflows with XML_PARSE_HUGE
- Drop tests, since they now require the XML Conformance Suite
- Drop SLES support (probably not working for ages anyway)

* Sun Jul 24 2022 Paul Howarth <paul@city-fan.org> - 2.9.14-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 20 2022 Paul Howarth <paul@city-fan.org> - 2.9.14-2.0.cf
- Rebuilt for Python 3.11

* Tue May  3 2022 Paul Howarth <paul@city-fan.org> - 2.9.14-1.0.cf
- Update to 2.9.14 (https://mail.gnome.org/archives/xml/2022-May/msg00000.html)
  - Includes fix for CVE-2022-29824: Integer overflow in xmlBuf and xmlBuffer

* Mon Feb 21 2022 Paul Howarth <paul@city-fan.org> - 2.9.13-1.0.cf
- Update to 2.9.13 (https://mail.gnome.org/archives/xml/2022-February/msg00009.html)
  - Includes fix for CVE-2022-23308: Use-after-free of ID and IDREF attributes
- Switch upstream source URL to download.gnome.org

* Fri Jan 21 2022 Paul Howarth <paul@city-fan.org> - 2.9.12-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Paul Howarth <paul@city-fan.org> - 2.9.12-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
- Fix dist tags for Alma and Rocky Linux

* Tue Jun  8 2021 Paul Howarth <paul@city-fan.org> - 2.9.12-5.0.cf
- Rebuilt for Python 3.10

* Thu Jun  3 2021 Paul Howarth <paul@city-fan.org> - 2.9.12-4.0.cf
- Fix xmlNodeDumpOutputInternal regression (#1965662)

* Tue May 25 2021 Paul Howarth <paul@city-fan.org> - 2.9.12-3.0.cf
- Rebuild to sync with Rawhide

* Mon May 24 2021 Paul Howarth <paul@city-fan.org> - 2.9.12-2.0.cf
- Fix python-lxml regression with 2.9.12
  https://gitlab.gnome.org/GNOME/libxml2/-/issues/255

* Fri May 14 2021 Paul Howarth <paul@city-fan.org> - 2.9.12-1.0.cf
- Update to 2.9.12 (https://mail.gnome.org/archives/xml/2021-May/msg00000.html)

* Fri May  7 2021 Paul Howarth <paul@city-fan.org> - 2.9.10-12.0.cf
- Fix CVE-2021-3537 (#1956524)

* Wed May  5 2021 Paul Howarth <paul@city-fan.org> - 2.9.10-11.0.cf
- Fix CVE-2021-3516 (#1954227), CVE-2021-3517 (#1954234) and CVE-2021-3518
  (#1954243)

* Thu Jan 28 2021 Paul Howarth <paul@city-fan.org> - 2.9.10-10.0.cf
- Drop EL-6 support
  - Use %%license unconditionally
  - Always build for Python 3
  - Drop workarounds for test failures on old distributions

* Sat Nov 14 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-9.0.cf
- Add correct fix for CVE-2020-24977 (#1877788)
- Build the Python extension with the PY_SSIZE_T_CLEAN macro to make it
  compatible with Python 3.10 (#1890878)

* Sun Sep 13 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-7.0.cf
- Fix integer overflow when comparing schema dates (CVE-2020-24977)
  https://bugzilla.redhat.com/show_bug.cgi?id=1877788

* Tue Jul 28 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sun May 31 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-5.0.cf
- Rebuilt for Python 3.9

* Sat Feb 15 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-4.0.cf
- Fix memory leak in xmlSchemaValidateStream (CVE-2019-20388)
  https://gitlab.gnome.org/GNOME/libxml2/merge_requests/68
- Fix infinite loop in xmlStringLenDecodeEntities (CVE-2020-7595)
  https://gitlab.gnome.org/GNOME/libxml2/merge_requests/63
 
* Fri Jan 31 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Jan  6 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-2.0.cf
- Fix relaxed approach to nested documents on object disposal (#1780573)

* Tue Nov  5 2019 Paul Howarth <paul@city-fan.org> - 2.9.10-1.2.cf
- Avoid multilib conflict due to doc/examples/Makefile

* Mon Nov  4 2019 Paul Howarth <paul@city-fan.org> - 2.9.10-1.1.cf
- Fix unicode errors in Python 3, patch from openSUSE
  (see https://bugzilla.gnome.org/show_bug.cgi?id=789714)
- Drop old patches, no longer needed

* Thu Oct 31 2019 Paul Howarth <paul@city-fan.org> - 2.9.10-1.0.cf
- Update to 2.9.10
  - This is a relatively large release, fixing a number of bugs and improving
    the code in many areas, among other things removing some recursive
    behaviour of the code in various places
  - Includes various portability fixes, documentation updates and clean-ups
  - See https://mail.gnome.org/archives/xml/2019-October/msg00014.html for full
    details
- Drop python2 sub-package from F-32, EL-8 onwards
- Add workaround for test failures with python3 < 3.6

* Sat Oct  5 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-6.0.cf
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 26 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-5.0.cf
- Rebuilt for Python 3.8 in Rawhide

* Mon Aug 12 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Feb  4 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jan  4 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-1.0.cf
- Update to 2.9.9
  - Security fixes, bug fixes as well as improvement and portability fixes for
    cygwin
  - Fix infinite loop in LZMA decompression (CVE-2018-9251, CVE-2018-14567)
  - Fix nullptr deref with XPath logic ops (CVE-2018-14404)
  - See https://mail.gnome.org/archives/xml/2019-January/msg00000.html for full
    details

* Mon Aug 13 2018 Paul Howarth <paul@city-fan.org> - 2.9.8-4.0.cf
- Various backports from upstream

* Mon Jul 16 2018 Paul Howarth <paul@city-fan.org> - 2.9.8-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Paul Howarth <paul@city-fan.org> - 2.9.8-2.0.cf
- Rebuild for Python 3.7 in Rawhide

* Wed Mar  7 2018 Paul Howarth <paul@city-fan.org> - 2.9.8-1.0.cf
- Update to 2.9.8
  - Bug fix and enhancement update
  - See https://mail.gnome.org/archives/xml//2018-March/msg00001.html
- Fix test compatibility with Python 3

* Fri Mar  2 2018 Paul Howarth <paul@city-fan.org> - 2.9.7-4.0.cf
- Rebuild with new LDFLAGS from redhat-rpm-config

* Fri Feb  9 2018 Paul Howarth <paul@city-fan.org> - 2.9.7-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Feb  5 2018 Paul Howarth <paul@city-fan.org> - 2.9.7-2.0.cf
- Make the XML entity recursion check more precise (CVE-2016-9597)
- Drop ldconfig scriptlets from Fedora 28 onwards
- Enable python3 sub-package for EL-7 builds
- Static library depends on devel package, not base package
- %%{?_isa} always available
- Make %%files list more explicit

* Fri Nov  3 2017 Paul Howarth <paul@city-fan.org> - 2.9.7-1.0.cf
- Update to 2.9.7
  - Bug fix, portability and enhancement update
  - See https://mail.gnome.org/archives/xml/2017-November/msg00001.html

* Fri Oct  6 2017 Paul Howarth <paul@city-fan.org> - 2.9.6-1.0.cf
- Update to 2.9.6
  - Bug fix update
  - See https://mail.gnome.org/archives/xml/2017-October/msg00003.html

* Wed Sep 20 2017 Paul Howarth <paul@city-fan.org> - 2.9.5-2.0.cf
- Report undefined XPath variable error message (#1493613, Gnome Bug #787941)

* Tue Sep  5 2017 Paul Howarth <paul@city-fan.org> - 2.9.5-1.0.cf
- Update to 2.9.5
  - Many bug fixes, including security issues
  - See https://mail.gnome.org/archives/xml/2017-September/msg00000.html

* Tue Aug 22 2017 Paul Howarth <paul@city-fan.org> - 2.9.4-5.0.cf
- Python 2 binary package renamed to python2-libxml2
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 2.9.4-4.0.cf
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Feb 11 2017 Paul Howarth <paul@city-fan.org> - 2.9.4-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Dec 24 2016 Paul Howarth <paul@city-fan.org> - 2.9.4-1.1.cf
- Apply very hacky patch that removes the PyVerify_fd symbol, not available in
  Python 3.6

* Tue May 24 2016 Paul Howarth <paul@city-fan.org> - 2.9.4-1.0.cf
- Update to 2.9.4
  - This is a big release, including a number of security patches, and there
    are also a significant number of 'normal' bug fixes and a fair number of
    portability fixes including a massive patch set for OS400
  - See https://mail.gnome.org/archives/xml/2016-May/msg00023.html
- Add patch to fix attribute decoding during XML schema validation
  (https://bugzilla.gnome.org/show_bug.cgi?id=766834)
- Simplify find commands using -delete

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 2.9.3-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Dec  3 2015 Paul Howarth <paul@city-fan.org> - 2.9.3-2.0.cf
- Fix obsoletes versions now that F22 has libxml2 2.9.3 (#1287262)

* Tue Nov 24 2015 Paul Howarth <paul@city-fan.org> - 2.9.3-1.0.cf
- Update to 2.9.3
  - CVE-2015-1819 Enforce the reader to run in constant memory
  - CVE-2015-5312 Another entity expansion issue
  - CVE-2015-7497 Avoid an heap buffer overflow in xmlDictComputeFastQKey
  - CVE-2015-7498 Avoid processing entities after encoding conversion failures
  - CVE-2015-7941-1 Stop parsing on entities boundaries errors
  - CVE-2015-7941-2 Cleanup conditional section error handling
  - CVE-2015-7942-1 Another variation of overflow in Conditional sections
  - CVE-2015-7942-2 Fix an error in previous Conditional section patch
  - CVE-2015-7499-1 Add xmlHaltParser() to stop the parser
  - CVE-2015-7499-2 Detect incoherency on GROW
  - CVE-2015-7500 Fix memory access error due to incorrect entities boundaries
  - CVE-2015-8035 Fix XZ compression support loop
  - CVE-2015-8242 Buffer overead with HTML parser in push mode
  - Various other bug fixes
    (see https://mail.gnome.org/archives/xml/2015-November/msg00012.html)
- Update SLES paths patch

* Sat Nov 14 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-9.0.cf
- Rebuild for Python 3.5 in Rawhide

* Mon Aug 31 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-7.0.cf
- Rename the Python 3 subpackage to python3-libxml2 as per guidelines

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Feb 22 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-4.0.cf
- Rebuilt for Fedora 23 Change
  https://fedoraproject.org/wiki/Changes/Harden_all_packages_with_position-independent_code

* Fri Feb 20 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-3.0.cf
- Add a python3 sub-package where possible

* Thu Dec 11 2014 Paul Howarth <paul@city-fan.org> - 2.9.2-2.1.cf
- Don't drop bogus (not in %%{_libdir}) provide for python shared object as
  it's required by python-dmidecode (surely a packaging bug?)

* Mon Oct 20 2014 Paul Howarth <paul@city-fan.org> - 2.9.2-2.0.cf
- Avoid corrupting the xml catalogs (#1153753)

* Fri Oct 17 2014 Paul Howarth <paul@city-fan.org> - 2.9.2-1.0.cf
- Update to 2.9.2
- Drop upstreamed patches
- Work around test issue on old 32-bit builds by dropping the test
- Run make in verbose mode so we can see which compiler flags were used

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 2.9.1-5.1.cf
- Use %%license where possible

* Mon Apr 28 2014 Paul Howarth <paul@city-fan.org> - 2.9.1-5.0.cf
- Enable xz compression support
- Fix a regression in xmlGetDocCompressMode() (#963716)
- Activate -O3 on ppc64 (#1051068)
- Drop support for old distributions prior to FC-5
  - Drop python 2.3 support
  - Drop %%defattr, redundant since rpm 4.4

* Mon Aug  5 2013 Paul Howarth <paul@city-fan.org> - 2.9.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> - 2.9.1-1.0.cf
- Update to 2.9.1
  - A couple more API entry points
  - Compatibility with python3
  - A lot of bug fixes
- Maintain timestamps where possible
- Add patch to fix python 2.6 compatibility (Gnome Bug #698364)
- Update patch for python 2.3 compatibility

* Mon Feb 11 2013 Paul Howarth <paul@city-fan.org> - 2.9.0-4.0.cf
- Don't ship examples/.deps in devel package

* Mon Nov 19 2012 Paul Howarth <paul@city-fan.org> - 2.9.0-3.0.cf
- workaround for crc/len check failure (#877567)

* Thu Oct 11 2012 Paul Howarth <paul@city-fan.org> - 2.9.0-2.0.cf
- Only ship the library documentation in the -devel package, not the main
  package (#864731)
- Don't ship the old ChangeLog file

* Tue Sep 11 2012 Paul Howarth <paul@city-fan.org> - 2.9.0-1.0.cf
- Update to 2.9.0 final
  - A few new API entry points
  - More resilient push parser mode
  - A lot of portability improvements
  - Faster XPath evaluation
  - A lot of bug fixes and smaller improvements

* Sun Aug 19 2012 Paul Howarth <paul@city-fan.org> - 2.9.0-0.1.0.rc1.cf
- Upstream release candidate 1 of 2.9.0
  - Introduce a small API change, but ABI compatible, see
    https://mail.gnome.org/archives/xml/2012-August/msg00005.html
  - Patches for php, gcc/libjava and evolution-data-connector are upstream
  - In case of problems, contact Daniel Veillard <veillard@redhat.com>
  - Many bug fixes including security aspects and small improvements

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 2.8.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 23 2012 Paul Howarth <paul@city-fan.org> - 2.8.0-1.0.cf
- New release 2.8.0
  - Add lzma compression support
  - Various documentation updates
  - Lots of portability fixes, particularly for Windows targets
  - Lots of bug fixes and other improvements
- Drop patches no longer needed
- Add %%clean section and run the test suite there
- Drop support for python 2.2

* Fri Jan 13 2012 Paul Howarth <paul@city-fan.org> - 2.7.8-10.0.cf
- Add XPath hardening patch from upstream (#732335)
- Fix missing error status in XPath evaluation (CVE-2011-2834)
- Make sure the parser returns when getting a Stop order (CVE-2011-3905)
- Fix an allocation error when copying entities (CVE-2011-3919)

* Wed Nov 16 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-9.0.cf
- Fix a heap-based buffer overflow caused by an off by one error in the
  encoding code (#724906, CVE-2011-0216)

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-8.0.cf
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-7.0.cf
- Fix a heap-based buffer overflow caused by adding a new namespace node to an
  existing nodeset or merging nodesets in XPath (#709750, CVE-2011-1944)
- Drop bogus provide for python shared object
- Nobody else likes macros for commands

* Fri Mar  4 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-6.0.cf
- Fix a double free in XPath (#665965, CVE-2010-4494)

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Nov  5 2010 Paul Howarth <paul@city-fan.org> - 2.7.8-4.0.cf
- Resync with Rawhide

* Thu Nov  4 2010 Paul Howarth <paul@city-fan.org> - 2.7.8-2.0.cf
- New release 2.7.8
  - Various bug fixes, including potential crashes
  - New non-destructive formatting option
  - Date parsing updated to RFC 5646
- Add patch to fix shared library versioning
- Add patch to support build of python bindings with python < 2.4

* Wed Jul 28 2010 Paul Howarth <paul@city-fan.org> - 2.7.7-2.1.cf
- Rebuild for python 2.7 in Rawhide

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 2.7.7-2.0.cf
- Fix dist tag for RHEL-6 Beta

* Mon Mar 15 2010 Paul Howarth <paul@city-fan.org> - 2.7.7-1.0.cf
- New release 2.7.7
  - Fix serious trouble with zlib >= 1.2.4
  - xmllint new option --xpath
  - Various HTML parser improvements
  - Includes a number of bug fixes

* Thu Feb 25 2010 Paul Howarth <paul@city-fan.org> - 2.7.6-2.0.cf
- dist tag for Rawhide no longer needs special-casing

* Wed Oct  7 2009 Paul Howarth <paul@city-fan.org> - 2.7.6-1.0.cf
- New release 2.7.6 (restore thread support off by default in 2.7.5)

* Fri Sep 25 2009 Paul Howarth <paul@city-fan.org> - 2.7.5-1.0.cf
- New release 2.7.5
  - Little data at startup patch upstreamed
  - Fix a couple of Relax-NG validation problems
  - A few more fixes

* Tue Sep 15 2009 Paul Howarth <paul@city-fan.org> - 2.7.4-2.0.cf
- Fix a problem with little data at startup affecting inkscape (#523002)

* Thu Sep 10 2009 Paul Howarth <paul@city-fan.org> - 2.7.4-1.0.cf
- New release 2.7.4, with security patches now upstream
- Lots of other fixes: see http://xmlsoft.org/news.html
- Update SLES patch to remove fuzz

* Wed Aug 12 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-4.0.cf
- Two patches for parsing problems CVE-2009-2414 and CVE-2009-2416

* Fri Jul 31 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 24 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-1.2.cf
- Force creation of debuginfo on SLES

* Mon Feb 23 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-1.1.cf
- Add SLES support in dist tag macros
- Add patch to fix up docs directories for SLES

* Tue Jan 20 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-1.0.CF
- New release 2.7.3, with security patches now upstream
- Limit default max size of text nodes
- Special parser mode for PHP
- Bug fixes and more compiler checks
- Source is now in "libxml2" directory on ftp server at xmlsoft.org

* Wed Dec 10 2008 Paul Howarth <paul@city-fan.org> - 2.7.2-7.0.CF
- Rebuild for python 2.6 on Rawhide

* Wed Dec  3 2008 Paul Howarth <paul@city-fan.org> - 2.7.2-6.0.CF
- Buildreq pkgconfig to get pkgconfig auto-provides (#473978)

* Mon Nov 17 2008 Paul Howarth <paul@city-fan.org> - 2.7.2-3
- Two patches for size overflow problems: CVE-2008-4225 (#470480) and
  CVE-2008-4226 (#470466)

* Fri Oct 31 2008 Paul Howarth <paul@city-fan.org> - 2.7.2-2
- Import from Fedora
- Make subpackages package require same-arch version of base package
- Use full pathnames for build-time command paths
- Install using DESTDIR rather than deprecated %%makeinstall macro
- Remove bogus exec permissions from source files
- Don't package static python binding

* Fri Oct  3 2008 Daniel Veillard <veillard@redhat.com> - 2.7.2-1.fc10
- New release 2.7.2
- Fixes the known problems in 2.7.1
- Increase the set of options when saving documents

* Thu Oct  2 2008 Daniel Veillard <veillard@redhat.com> - 2.7.1-2.fc10
- Fix a nasty bug in 2.7.x, http://bugzilla.gnome.org/show_bug.cgi?id=554660

* Mon Sep  1 2008 Daniel Veillard <veillard@redhat.com> - 2.7.1-1.fc10
- Fix python serialization which was broken in 2.7.0
- Resolve: rhbz#460774

* Sat Aug 30 2008 Daniel Veillard <veillard@redhat.com> - 2.7.0-1.fc10
- Upstream release of 2.7.0
- Switch to XML 1.0 5th edition
- Switch to RFC 3986 for URI parsing
- better entity handling
- Option to remove hardcoded limitations in the parser
- More testing
- A new API to allocate entity nodes
- And lot of fixes and clanups

* Mon Aug 25 2008 Daniel Veillard <veillard@redhat.com> - 2.6.32-4.fc10
- Fix for entities recursion problem
- Resolve: rhbz#459714

* Fri May 30 2008 Daniel Veillard <veillard@redhat.com> - 2.6.32-3.fc10
- Cleanup based on Fedora packaging guidelines, should fix #226079
- Separate a -static package

* Thu May 15 2008 Daniel Veillard <veillard@redhat.com> - 2.6.32-2.fc10
- Try to fix multiarch problems like #440206

* Tue Apr  8 2008 Daniel Veillard <veillard@redhat.com> - 2.6.32-1.fc9
- Upstream release 2.6.32 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Wed Feb 20 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.6.31-2
- Autorebuild for GCC 4.3

* Fri Jan 11 2008 Daniel Veillard <veillard@redhat.com> - 2.6.31-1.fc9
- Upstream release 2.6.31 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Thu Aug 23 2007 Daniel Veillard <veillard@redhat.com> - 2.6.30-1
- Upstream release 2.6.30 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Tue Jun 12 2007 Daniel Veillard <veillard@redhat.com> - 2.6.29-1
- Upstream release 2.6.29 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Wed May 16 2007 Matthias Clasen <mclasen@redhat.com> - 2.6.28-2
- Bump revision to fix N-V-R problem

* Tue Apr 17 2007 Daniel Veillard <veillard@redhat.com> - 2.6.28-1
- Upstream release 2.6.28 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 2.6.27-2
- Rebuild against python 2.5

* Wed Oct 25 2006 Daniel Veillard <veillard@redhat.com> - 2.6.27-1
- Upstream release 2.6.27 see http://xmlsoft.org/news.html
- Very large amount of bug fixes reported upstream

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.6.26-2.1.1
- Rebuild

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.6.26-2.1
- Rebuild

* Wed Jun  7 2006 Daniel Veillard <veillard@redhat.com> - 2.6.26-2
- Fix bug #192873

* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com> - 2.6.26-1
- Upstream release 2.6.26 see http://xmlsoft.org/news.html

* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com>
- Upstream release 2.6.25 broken, do not ship!

